==> haskell-dyre-0.8.12-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dyre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dyre
version:              0.8.12
visibility:           public
id:                   dyre-0.8.12-LehewHGycDhAdUacaP2VD
key:                  dyre-0.8.12-LehewHGycDhAdUacaP2VD
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            beta
homepage:             http://github.com/willdonnelly/dyre
synopsis:             Dynamic reconfiguration in Haskell
description:
    Dyre implements dynamic reconfiguration facilities after the
    style of Xmonad. Dyre aims to be as simple as possible without
    sacrificing features, and places an emphasis on simplicity of
    integration with an application.
    A full introduction with a complete example project can be found
    in the documentation for '\''Config.Dyre'\''

category:             Development, Configuration
abi:                  e8fcf7d97fc29c5ae0df17fbf8c1fc7f
exposed:              True
exposed-modules:
    Config.Dyre Config.Dyre.Compat Config.Dyre.Compile
    Config.Dyre.Options Config.Dyre.Params Config.Dyre.Paths
    Config.Dyre.Relaunch

import-dirs:          /usr/lib/ghc-8.8.2/site-local/dyre-0.8.12
library-dirs:         /usr/lib/ghc-8.8.2/site-local/dyre-0.8.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/dyre-0.8.12
hs-libraries:         HSdyre-0.8.12-LehewHGycDhAdUacaP2VD
depends:
    base-4.13.0.0 binary-0.8.7.0 directory-1.3.4.0
    executable-path-0.0.3.1-HzRZG9S58EmFF6j1BDdKjn filepath-1.4.2.1
    ghc-paths-0.1.0.12-6yfxCcKnGxxC3UhlLpLlce
    io-storage-0.3-LbYyYgzZEd6JNGbqmtbKje process-1.6.7.0 time-1.9.3
    unix-2.7.2.2 xdg-basedir-0.2.2-1SelnM9wFsoDwM3RXDG70I

haddock-interfaces:   /usr/share/doc/haskell-dyre/html/dyre.haddock
haddock-html:         /usr/share/doc/haskell-dyre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dyre-0.8.12-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dyre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dyre
version:              0.8.12
visibility:           public
id:                   dyre-0.8.12-BxKV0ifmpo0Fmsfl7TW9RT
key:                  dyre-0.8.12-BxKV0ifmpo0Fmsfl7TW9RT
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            beta
homepage:             http://github.com/willdonnelly/dyre
synopsis:             Dynamic reconfiguration in Haskell
description:
    Dyre implements dynamic reconfiguration facilities after the
    style of Xmonad. Dyre aims to be as simple as possible without
    sacrificing features, and places an emphasis on simplicity of
    integration with an application.
    A full introduction with a complete example project can be found
    in the documentation for '\''Config.Dyre'\''

category:             Development, Configuration
abi:                  d8d54c602099b0175891173590f825c2
exposed:              True
exposed-modules:
    Config.Dyre Config.Dyre.Compat Config.Dyre.Compile
    Config.Dyre.Options Config.Dyre.Params Config.Dyre.Paths
    Config.Dyre.Relaunch

import-dirs:          /usr/lib/ghc-8.8.3/site-local/dyre-0.8.12
library-dirs:         /usr/lib/ghc-8.8.3/site-local/dyre-0.8.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/dyre-0.8.12
hs-libraries:         HSdyre-0.8.12-BxKV0ifmpo0Fmsfl7TW9RT
depends:
    base-4.13.0.0 binary-0.8.7.0 directory-1.3.6.0
    executable-path-0.0.3.1-Dswj5xYJKwHKBoMwNzgVzv filepath-1.4.2.1
    ghc-paths-0.1.0.12-6yfxCcKnGxxC3UhlLpLlce
    io-storage-0.3-LbYyYgzZEd6JNGbqmtbKje process-1.6.8.0 time-1.9.3
    unix-2.7.2.2 xdg-basedir-0.2.2-LVv1BwILCJR4v8JryE8LvJ

haddock-interfaces:   /usr/share/doc/haskell-dyre/html/dyre.haddock
haddock-html:         /usr/share/doc/haskell-dyre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
